@@ -14,6 +14,7 @@
 """Attribute Annotations implementation"""
 import logging
 
+
 try:
     from collections.abc import MutableMapping as DictMixin
 except ImportError:
@@ -22,17 +23,19 @@ except ImportError:
 
 try:
     from BTrees.OOBTree import OOBTree as _STORAGE
-except ImportError: # pragma: no cover
+except ImportError:  # pragma: no cover
     logging.getLogger(__name__).warning(
         'BTrees not available: falling back to dict for attribute storage')
     _STORAGE = dict
 
-from zope import component, interface
+from zope import component
+from zope import interface
 from zope.annotation import interfaces
 
 
 _EMPTY_STORAGE = _STORAGE()
 
+
 @interface.implementer(interfaces.IAnnotations)
 @component.adapter(interfaces.IAttributeAnnotatable)
 class AttributeAnnotations(DictMixin):
