@@ -15,11 +15,13 @@ import unittest
 
 from zope.annotation.tests.annotations import AnnotationsTestBase
 
+
 class AttributeAnnotationsTest(AnnotationsTestBase, unittest.TestCase):
 
     def setUp(self):
-        from zope.testing import cleanup
         from zope.interface import implementer
+        from zope.testing import cleanup
+
         from zope.annotation.attribute import AttributeAnnotations
         from zope.annotation.interfaces import IAttributeAnnotatable
 
@@ -32,10 +34,14 @@ class AttributeAnnotationsTest(AnnotationsTestBase, unittest.TestCase):
         self.obj = Dummy()
         self.annotations = AttributeAnnotations(self.obj)
 
-    def tearDown(test=None):
+    def tearDown(self):
         from zope.testing import cleanup
         cleanup.tearDown()
 
+    def testInterfaceVerifies(self):
+        super(AttributeAnnotationsTest, self).testInterfaceVerifies()
+        self.assertIs(self.obj, self.annotations.__parent__)
+
 
 def test_suite():
     return unittest.defaultTestLoader.loadTestsFromName(__name__)
