@@ -14,34 +14,38 @@
 
 import unittest
 
-from zope.annotation import factory
-
-from zope import interface
-from zope import component
 from zope.location.interfaces import ILocation
 
+from zope import component
+from zope import interface
+from zope.annotation import factory
 from zope.annotation.interfaces import IAnnotations
 
 
 class ITarget(interface.Interface):
     pass
 
+
 class IContext(IAnnotations):
     pass
 
+
 @interface.implementer(ITarget)
 @component.adapter(IContext)
 class Target(object):
     pass
 
+
 @interface.implementer(IContext)
 class Context(dict):
     pass
 
+
 class TestFactory(unittest.TestCase):
 
-    assertRaisesRegex = getattr(unittest.TestCase, 'assertRaisesRegex',
-                                getattr(unittest.TestCase, 'assertRaisesRegexp'))
+    assertRaisesRegex = getattr(
+        unittest.TestCase, 'assertRaisesRegex',
+        getattr(unittest.TestCase, 'assertRaisesRegexp'))  # PY2
 
     def test_no_adapts(self):
         self.assertRaisesRegex(TypeError, "Missing.*on annotation",
